bayespy.inference.vmp.nodes.categorical.CategoricalMoments.get_converter
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalMoments.get_converter